FLAC
====

.. currentmodule:: mutagen

.. automodule:: mutagen.flac

.. autoclass:: mutagen.flac.FLAC
    :show-inheritance:
    :members:
    :exclude-members: vc, METADATA_BLOCKS, load, add_vorbiscomment

.. autoclass:: mutagen.flac.StreamInfo
    :members:

    :bases: `mutagen.StreamInfo`

.. autoclass:: mutagen.flac.Picture
    :members:

.. autoclass:: mutagen.flac.CueSheet
    :members:

.. autoclass:: mutagen.flac.CueSheetTrack
    :members:

.. autoclass:: mutagen.flac.CueSheetTrackIndex
    :members:

.. autoclass:: mutagen.flac.SeekTable
    :members:
